guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

12/15: gnu: ruby-hamster: Fix build.


From: guix-commits
Subject: 12/15: gnu: ruby-hamster: Fix build.
Date: Mon, 10 Jul 2023 07:40:29 -0400 (EDT)

cbaines pushed a commit to branch master
in repository guix.

commit 81a2a0f8d10dc530dbf46d1c59e7a791d3a8770e
Author: Christopher Baines <mail@cbaines.net>
AuthorDate: Mon Jul 10 11:26:36 2023 +0100

    gnu: ruby-hamster: Fix build.
    
    * gnu/packages/ruby.scm (ruby-hamster)[arguments]: Run tests with ruby-2.7 
and
    update style.
---
 gnu/packages/ruby.scm | 43 ++++++++++++++++++++++---------------------
 1 file changed, 22 insertions(+), 21 deletions(-)

diff --git a/gnu/packages/ruby.scm b/gnu/packages/ruby.scm
index 7fb8da9641..b96daad0ff 100644
--- a/gnu/packages/ruby.scm
+++ b/gnu/packages/ruby.scm
@@ -3698,27 +3698,28 @@ engine.")
           "1n1lsh96vnyc1pnzyd30f9prcsclmvmkdb3nm5aahnyizyiy6lar"))))
   (build-system ruby-build-system)
   (arguments
-   '(#:phases
-     (modify-phases %standard-phases
-       (add-after 'unpack 'remove-unnecessary-dependencies
-         (lambda _
-           ;; pry is a debugging tool, and is unnecessary when running the
-           ;; tests
-           (substitute* "spec/lib/hamster/vector/insert_spec.rb"
-             (("require 'pry'") ""))
-           (substitute* "spec/spec_helper.rb"
-             (("require \"pry\"") "")
-             ;; CodeClimate is an online service, and is unnecessary for
-             ;; running the tests
-             (("require \"codeclimate-test-reporter\"") "")
-             (("CodeClimate.*\n") ""))
-           #t))
-       ;; No Rakefile is included, so run rspec directly.
-       (replace 'check
-         (lambda* (#:key tests? #:allow-other-keys)
-           (when tests?
-             (invoke "rspec"))
-           #t)))))
+   (list
+    ;; Only supports Ruby 2 currently
+    #:ruby ruby-2.7
+    #:phases
+    #~(modify-phases %standard-phases
+        (add-after 'unpack 'remove-unnecessary-dependencies
+          (lambda _
+            ;; pry is a debugging tool, and is unnecessary when running the
+            ;; tests
+            (substitute* "spec/lib/hamster/vector/insert_spec.rb"
+              (("require 'pry'") ""))
+            (substitute* "spec/spec_helper.rb"
+              (("require \"pry\"") "")
+              ;; CodeClimate is an online service, and is unnecessary for
+              ;; running the tests
+              (("require \"codeclimate-test-reporter\"") "")
+              (("CodeClimate.*\n") ""))))
+        ;; No Rakefile is included, so run rspec directly.
+        (replace 'check
+          (lambda* (#:key tests? #:allow-other-keys)
+            (when tests?
+              (invoke "ruby" (which "rspec"))))))))
   (propagated-inputs
    (list ruby-concurrent))
   (native-inputs



reply via email to

[Prev in Thread] Current Thread [Next in Thread]